diff --git a/src/main/java/envoy/data/LoginCredentials.java b/src/main/java/envoy/data/LoginCredentials.java
index 86b166c..a8d9c6b 100644
--- a/src/main/java/envoy/data/LoginCredentials.java
+++ b/src/main/java/envoy/data/LoginCredentials.java
@@ -9,55 +9,29 @@ import java.util.Formatter;
* Project: envoy-common
* File: LoginCredentials.java
* Created: 29.12.2019
- *
+ *
* @author Kai S. K. Engelbart
* @since Envoy Common v0.2-alpha
*/
public class LoginCredentials implements Serializable {
- private final String name;
- private final byte[] passwordHash;
-
- private static final long serialVersionUID = -7395245059059523314L;
+ private static final long serialVersionUID = -7395245059059523314L;
+ private final String name;
+ private final byte[] passwordHash;
/**
* Creates an in stance of {@link LoginCredentials}.
- *
+ *
* @param name the name of the user
* @param password the password of the user (will be converted to a hash)
- * @throws NoSuchAlgorithmException
+ * @throws NoSuchAlgorithmException if the algorithm used is unknown
+ * @since Envoy Common v0.2-alpha
*/
public LoginCredentials(String name, char[] password) throws NoSuchAlgorithmException {
this.name = name;
passwordHash = getSha256(toByteArray(password));
}
- @Override
- public String toString() {
- Formatter form = new Formatter();
- form.format("LoginCredentials[name=%s,passwordHash=", name);
- for (int i = 0; i < passwordHash.length; i++)
- form.format("%02x", passwordHash[i]);
- form.format("]");
- String str = form.toString();
- form.close();
- return str;
- }
-
- private byte[] toByteArray(char[] chars) {
- byte[] bytes = new byte[chars.length * 2];
- for (int i = 0; i < chars.length; ++i) {
- bytes[i * 2] = (byte) (chars[i] >> 8);
- bytes[i * 2 + 1] = (byte) (chars[i]);
- }
- return bytes;
- }
-
- private byte[] getSha256(byte[] input) throws NoSuchAlgorithmException {
- MessageDigest md = MessageDigest.getInstance("SHA-256");
- return md.digest(input);
- }
-
/**
* @return the name of the user performing the login
* @since Envoy Common v0.2-alpha
@@ -69,4 +43,31 @@ public class LoginCredentials implements Serializable {
* @since Envoy Common v0.2-alpha
*/
public byte[] getPasswordHash() { return passwordHash; }
+
+ private byte[] getSha256(byte[] input) throws NoSuchAlgorithmException {
+ MessageDigest md = MessageDigest.getInstance("SHA-256");
+ return md.digest(input);
+ }
+
+ private byte[] toByteArray(char[] chars) {
+ byte[] bytes = new byte[chars.length * 2];
+ for (int i = 0; i < chars.length; ++i) {
+ bytes[i * 2] = (byte) (chars[i] >> 8);
+ bytes[i * 2 + 1] = (byte) (chars[i]);
+ }
+ return bytes;
+ }
+
+ @Override
+ public String toString() {
+ try (Formatter form = new Formatter()) {
+ form.format("LoginCredentials[name=%s,passwordHash=", name);
+ for (byte element : passwordHash) {
+ form.format("%02x", element);
+ }
+ form.format("]");
+ String str = form.toString();
+ return str;
+ }
+ }
}
\ No newline at end of file
diff --git a/src/main/java/envoy/data/MessageAttachment.java b/src/main/java/envoy/data/MessageAttachment.java
new file mode 100644
index 0000000..fa86998
--- /dev/null
+++ b/src/main/java/envoy/data/MessageAttachment.java
@@ -0,0 +1,26 @@
+package envoy.data;
+
+import java.io.Serializable;
+
+import javax.swing.Scrollable;
+
+/**
+ * This Interface should be used for any type supposed to be a {@link Message}
+ * attachment (i.e. images or sound).
+ *
+ * Project: envoy-common
+ * File: MessageAttachment.java
+ * Created: 30 Dec 2019
+ *
+ * @author Leon Hofmeister
+ * @param the type of this message attachment
+ * @since Envoy Common v0.2-alpha
+ */
+public interface MessageAttachment extends Serializable, Scrollable {
+
+ /**
+ * @return the type implementing this interface
+ * @since Envoy Common v0.2-alpha
+ */
+ T get();
+}
diff --git a/src/main/java/envoy/data/TextMessage.java b/src/main/java/envoy/data/TextMessage.java
deleted file mode 100644
index cbee210..0000000
--- a/src/main/java/envoy/data/TextMessage.java
+++ /dev/null
@@ -1,54 +0,0 @@
-package envoy.data;
-
-import java.text.SimpleDateFormat;
-
-/**
- * Represents a {@link Message} with content that is comprised of text.
- *
- * Project: envoy-common
- * File: TextMessage.java
- * Created: 28.12.2019
- *
- * @author Kai S. K. Engelbart
- * @since Envoy Common v0.2-alpha
- */
-public class TextMessage extends Message {
-
- private final String content;
-
- private static final long serialVersionUID = 1538164720632899917L;
-
- /**
- * Initializes a {@link TextMessage} from the client's perspective. The current
- * date
- * is used as the message date and the status is set to
- * {@link envoy.data.Message.MessageStatus#WAITING}.
- *
- * @param id unique ID
- * @param sender the user who sends the message
- * @param recipient the user who receives the message
- * @param content the content of the message
- * @since Envoy Common v0.2-alpha
- */
- public TextMessage(long id, User sender, User recipient, String content) {
- super(id, sender, recipient);
- this.content = content;
- }
-
- @Override
- public String toString() {
- return String.format("TextMessage[id=%d,sender=%s,recipient=%s,date=%s,status=%s,content=%s]",
- getId(),
- getSender(),
- getRecipient(),
- new SimpleDateFormat("dd.MM.yyyy HH:mm:ss").format(getDate()),
- getStatus(),
- content);
- }
-
- /**
- * @return the content of this {@link TextMessage}
- * @since Envoy Common v0.2-alpha
- */
- public String getContent() { return content; }
-}
\ No newline at end of file
diff --git a/src/main/java/envoy/data/User.java b/src/main/java/envoy/data/User.java
index afca690..6109218 100644
--- a/src/main/java/envoy/data/User.java
+++ b/src/main/java/envoy/data/User.java
@@ -9,23 +9,53 @@ import java.io.Serializable;
* Project: envoy-common
* File: User.java
* Created: 28.12.2019
- *
+ *
* @author Kai S. K. Engelbart
* @since Envoy Common v0.2-alpha
*/
public class User implements Serializable {
- private final long id;
- private final String name;
+ /**
+ * This enum defines all possible statuses a user can have.
+ *
+ * @since Envoy Common v0.2-alpha
+ */
+ public static enum UserStatus {
- private UserStatus status;
+ /**
+ * select this, if a user is online and can be interacted with
+ */
+ ONLINE,
+
+ /**
+ * select this, if a user is online but unavailable at the moment (sudden
+ * interruption)
+ */
+ AWAY,
+
+ /**
+ * select this, if a user is online but unavailable at the moment (polite way)
+ */
+ BUSY,
+
+ /**
+ * select this, if a user is offline
+ */
+ OFFLINE;
+ }
private static final long serialVersionUID = 3530947374856708236L;
+ private final long id;
+
+ private final String name;
+
+ private UserStatus status;
+
/**
* Initializes a {@link User}. The {@link UserStatus} is set to
* {@link UserStatus#OFFLINE}.
- *
+ *
* @param id unique ID
* @param name user name
* @since Envoy Client v0.2-alpha
@@ -36,9 +66,6 @@ public class User implements Serializable {
status = UserStatus.OFFLINE;
}
- @Override
- public String toString() { return String.format("User[id=%d,name=%s,status=%s]", id, name, status); }
-
/**
* @return the ID of this {@link User}
* @since Envoy Client v0.2-alpha
@@ -59,13 +86,12 @@ public class User implements Serializable {
/**
* Sets the current status of this user
- *
+ *
* @param status the status to set
* @since Envoy Client v0.2-alpha
*/
public void setStatus(UserStatus status) { this.status = status; }
- public static enum UserStatus {
- ONLINE, AWAY, BUSY, OFFLINE;
- }
+ @Override
+ public String toString() { return String.format("User[id=%d,name=%s,status=%s]", id, name, status); }
}
\ No newline at end of file
diff --git a/src/main/java/envoy/exception/EnvoyException.java b/src/main/java/envoy/exception/EnvoyException.java
index 00f9946..650e1bb 100644
--- a/src/main/java/envoy/exception/EnvoyException.java
+++ b/src/main/java/envoy/exception/EnvoyException.java
@@ -1,20 +1,35 @@
-package envoy.exception;
-
-/**
- * Project: envoy-common
- * File: EnvoyException.java
- * Created: 27 Oct 2019
- *
- * @author Kai S. K. Engelbart
- * @since Envoy v0.1-alpha
- */
-public class EnvoyException extends Exception {
-
- private static final long serialVersionUID = 2096147309395387479L;
-
- public EnvoyException(String message, Throwable cause) { super(message, cause); }
-
- public EnvoyException(String message) { super(message); }
-
- public EnvoyException(Throwable cause) { super(cause); }
-}
+package envoy.exception;
+
+/**
+ * Project: envoy-common
+ * File: EnvoyException.java
+ * Created: 27 Oct 2019
+ *
+ * @author Kai S. K. Engelbart
+ * @since Envoy v0.1-alpha
+ */
+public class EnvoyException extends Exception {
+
+ private static final long serialVersionUID = 2096147309395387479L;
+
+ /**
+ * @param message the message to display once this Exception is thrown
+ * @since Envoy Common v0.2-alpha
+ */
+ public EnvoyException(String message) { super(message); }
+
+ /**
+ * @param message the message to display once this Exception is thrown
+ * @param cause the {@link Throwable} which resulted in the throw of an
+ * EnvoyException
+ * @since Envoy Common v0.2-alpha
+ */
+ public EnvoyException(String message, Throwable cause) { super(message, cause); }
+
+ /**
+ * @param cause the {@link Throwable} which resulted in the throw of an
+ * EnvoyException
+ * @since Envoy Common v0.2-alpha
+ */
+ public EnvoyException(Throwable cause) { super(cause); }
+}
diff --git a/src/main/java/envoy/util/SerializationUtils.java b/src/main/java/envoy/util/SerializationUtils.java
index dfd166b..c070733 100644
--- a/src/main/java/envoy/util/SerializationUtils.java
+++ b/src/main/java/envoy/util/SerializationUtils.java
@@ -11,28 +11,29 @@ import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Serializable;
-import envoy.exception.EnvoyException;
-
/**
* Project: envoy-client
* File: SerializationUtils.java
* Created: 23.12.2019
- *
+ *
* @author Kai S. K. Engelbart
* @since Envoy Common v0.2-alpha
*/
public class SerializationUtils {
- private SerializationUtils() {}
+ private static byte[] intToBytes(int n) { return new byte[] { (byte) (n >>> 24), (byte) (n >>> 16), (byte) (n >>> 8), (byte) n }; }
/**
* Deserializes an arbitrary {@link Serializable} object from a file.
- *
+ *
* @param the type of the object to deserialize
- * @param file the file deserialize from
+ * @param file the file to deserialize from
* @param serializedClass the class of the object to deserialize
* @return the deserialized object
- * @throws EnvoyException if an error occurred during deserialization
+ * @throws IOException if something failed while deserializing the
+ * object
+ * @throws ClassNotFoundException if the deserialized object can not be linked
+ * to a class
* @since Envoy Common v0.2-alpha
*/
public static T read(File file, Class serializedClass) throws IOException, ClassNotFoundException {
@@ -40,6 +41,18 @@ public class SerializationUtils {
return read(new FileInputStream(file), serializedClass);
}
+ /**
+ * @param the deserialized object
+ * @param in the {@link InputStream} of a serialized Object
+ * @param serializedClass the object type to convert the deserialized object
+ * into
+ * @return the deserialized object
+ * @throws IOException if something failed while deserializing the
+ * object
+ * @throws ClassNotFoundException if the deserialized object can not be linked
+ * to a class
+ * @since Envoy Common v0.2-alpha
+ */
public static T read(InputStream in, Class serializedClass) throws IOException, ClassNotFoundException {
try (ObjectInputStream oin = new ObjectInputStream(in)) {
return serializedClass.cast(oin.readObject());
@@ -48,7 +61,7 @@ public class SerializationUtils {
/**
* Serializes an arbitrary object to a file.
- *
+ *
* @param file the file to serialize to
* @param obj the object to serialize
* @throws IOException if an error occurred during serialization
@@ -69,7 +82,7 @@ public class SerializationUtils {
/**
* Serializes an object and writes it into an output stream preceded by 4 bytes
* containing the number of serialized bytes.
- *
+ *
* @param obj the object to serialize
* @param out the output stream to serialize to
* @throws IOException if an error occurred during serialization
@@ -90,5 +103,5 @@ public class SerializationUtils {
out.write(objBytes);
}
- private static byte[] intToBytes(int n) { return new byte[] { (byte) (n >>> 24), (byte) (n >>> 16), (byte) (n >>> 8), (byte) n }; }
+ private SerializationUtils() {}
}
\ No newline at end of file
diff --git a/src/main/java/envoy/data/Message.java b/src/main/java/envoy/data/Message.java
index 555c751..acb3d6f 100644
--- a/src/main/java/envoy/data/Message.java
+++ b/src/main/java/envoy/data/Message.java
@@ -1,7 +1,9 @@
package envoy.data;
import java.io.Serializable;
+import java.text.SimpleDateFormat;
import java.util.Date;
+import java.util.Optional;
/**
* Represents a unique message with a unique, numeric ID. Further metadata
@@ -11,68 +13,121 @@ import java.util.Date;
* Project: envoy-common
* File: Message.java
* Created: 28.12.2019
- *
+ *
* @author Kai S. K. Engelbart
+ * @author Leon Hofmeister
* @since Envoy Common v0.2-alpha
*/
public abstract class Message implements Serializable {
- private final long id;
- private final User sender, recipient;
- private final Date date;
+ /**
+ * This enum defines all possible statuses a {link Message} can have.
+ *
+ * @since Envoy Common v0.2-alpha
+ */
+ public static enum MessageStatus {
+
+ /**
+ * is selected, if a message was sent but not received by the server yet.
+ */
+ WAITING,
+
+ /**
+ * is selected, if a sent message was received by the server.
+ */
+ SENT,
+
+ /**
+ * is selected, if a message was delivered from the server to the recipient, but
+ * has not been read yet.
+ */
+ RECEIVED,
+
+ /**
+ * is selected, if a recipient opened the corresponding chat of said message.
+ */
+ READ
+ }
+
+ private static final long serialVersionUID = -4393477412979594435L;
+ private final long id;
+
+ private final User sender, recipient;
+
+ private final Date date;
+
+ private final String text;
+
+ private final MessageAttachment> messageAttachment;
private MessageStatus status;
- private static final long serialVersionUID = -4393477412979594435L;
-
/**
* Initializes a {@link Message} from the client's perspective. The current date
* is used as the message date and the status is set to
* {@link MessageStatus#WAITING}.
*
* @param id unique ID
* @param sender the user who sends the message
* @param recipient the user who receives the message
* @since Envoy Common v0.2-alpha
*/
- public Message(long id, User sender, User recipient) {
- this.id = id;
- this.sender = sender;
- this.recipient = recipient;
- date = new Date();
- status = MessageStatus.WAITING;
+ public Message(long id, User sender, User recipient, String text, @SuppressWarnings("rawtypes") Optional attachment) {
+ this.id = id;
+ this.sender = sender;
+ this.recipient = recipient;
+ this.text = text;
+ this.messageAttachment = attachment.isEmpty() ? null : attachment.get();
+ this.date = new Date();
+ this.status = MessageStatus.WAITING;
}
- /**
- * @return the ID of this message
- * @since Envoy Common v0.2-alpha
- */
- public long getId() { return id; }
-
- /**
- * @return the sender of this message
- * @since Envoy Common v0.2-alpha
- */
- public User getSender() { return sender; }
-
- /**
- * @return the recipient of this message
- * @since Envoy Common v0.2-alpha
- */
- public User getRecipient() { return recipient; }
-
/**
* @return the date at which this message was created
* @since Envoy Common v0.2-alpha
*/
public Date getDate() { return date; }
+ /**
+ * @return the ID of this message
+ * @since Envoy Common v0.2-alpha
+ */
+ public long getId() { return id; }
+
+ /**
+ * @param the type of the message attachment
+ * @return the messageAttachment
+ * @since Envoy Common v0.2-alpha
+ */
+ public MessageAttachment> getMessageAttachment() { return messageAttachment; }
+
+ /**
+ * @return the recipient of this message
+ * @since Envoy Common v0.2-alpha
+ */
+ public User getRecipient() { return recipient; }
+
+ /**
+ * @return the sender of this message
+ * @since Envoy Common v0.2-alpha
+ */
+ public User getSender() { return sender; }
+
/**
* @return the current status of this message
* @since Envoy Common v0.2-alpha
*/
public MessageStatus getStatus() { return status; }
+ /**
+ * @return the text content of this message
+ * @since Envoy Common v0.2-alpha
+ */
+ public String getText() { return text; }
+
/**
* Changes the current {@link MessageStatus} to the next logical status.
*
@@ -83,7 +138,7 @@ public abstract class Message implements Serializable {
* {@link MessageStatus#RECEIVED}
* {@link MessageStatus#READ}
*
- *
+ *
* @since Envoy Common v0.2-alpha
*/
public void nextStatus() {
@@ -91,7 +146,14 @@ public abstract class Message implements Serializable {
status = MessageStatus.values()[status.ordinal() + 1];
}
- public static enum MessageStatus {
- WAITING, SENT, RECEIVED, READ
+ @Override
+ public String toString() {
+ return String.format("TextMessage[id=%d,sender=%s,recipient=%s,date=%s,status=%s,content=%s]",
+ id,
+ sender,
+ recipient,
+ new SimpleDateFormat("dd.MM.yyyy HH:mm:ss").format(date),
+ status,
+ text);
}
}
\ No newline at end of file
@@ -11,68 +13,121 @@ import java.util.Date;
* is used as the message date and the status is set to
* {@link MessageStatus#WAITING}.
- *
- * @param id unique ID
- * @param sender the user who sends the message
- * @param recipient the user who receives the message
+ *
+ * @param the type of the attachment
+ * @param id unique ID
+ * @param sender the user who sends the message
+ * @param recipient the user who receives the message
+ * @param text the text content of the message
+ * @param attachment the attachment of the message, if present
* @since Envoy Common v0.2-alpha
*/